<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja" sourcelanguage="en">
  <context>
    <name>StartPage</name>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="42"/>
      <source>Start</source>
      <translation>開始</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="43"/>
      <source>Documents</source>
      <translation>ドキュメント</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="44"/>
      <source>Help</source>
      <translation>ヘルプ</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="45"/>
      <source>Activity</source>
      <translation>アクティビティ</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="46"/>
      <source>Recent files</source>
      <translation>最近使用したファイル</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="47"/>
      <source>Tip</source>
      <translation>ヒント</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="48"/>
      <source>Adjust the number of recent files to be shown here in menu Edit -&gt; Preferences -&gt; General -&gt; Size of recent file list</source>
      <translation>ここに表示される最近使用したファイルの数を調整するにはメニューの 編集→設定→標準→最近使用したファイル一覧のサイズ を使用してください。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="49"/>
      <source>Examples</source>
      <translation>サンプル</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="50"/>
      <source>General documentation</source>
      <translation>一般ドキュメント</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="51"/>
      <source>User hub</source>
      <translation>ユーザーハブ</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="52"/>
      <source>This section contains documentation useful for FreeCAD users in general: a list of all the workbenches, detailed instructions on how to install and use the FreeCAD application, tutorials, and all you need to get started.</source>
      <translation>このセクションには一般的な FreeCAD ユーザーにとって役に立つドキュメントがあります。全てのワークベンチのリスト、FreeCAD アプリケーションのインストールと使い方の詳しいやり方、チュートリアルなど始めるのに必要な全てがあります。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="53"/>
      <source>Power users hub</source>
      <translation>パワーユーザーハブ</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="54"/>
      <source>This section gathers documentation for advanced users and people interested in writing python scripts. You will also find there a repository of macros, instructions on how to install and use them, and more information about customizing FreeCAD to your specific needs.</source>
      <translation>このセクションには上級者ユーザーや Python スクリプトを書くことに興味がある人たちのためのドキュメントが集められています。またマクロのレポジトリーやそれらをどのようにインストールし使うかについてのやり方、そして必要に合わせた FreeCAD のカスタマイズについての詳しい情報もあります。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>Developers hub</source>
      <translation>開発者ハブ</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>This section contains material for developers: How to compile FreeCAD yourself, how the FreeCAD source code is structured + how to navigate in it, how to develop new workbenches and/or embed FreeCAD in your own application.</source>
      <translation>このセクションには開発者のための情報があります。自分で FreeCAD をコンパイルする方法、FreeCAD のソースコードがどのように構成されていてそれをどのように読み進めるのか、また新しいワークベンチの開発方法や自分のアプリケーションに FreeCAD を埋め込む方法についてなどがあります。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="57"/>
      <source>Manual</source>
      <translation>マニュアル</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="58"/>
      <source>The FreeCAD manual is another, more linear way to present the information contained in this wiki. It is made to be read like a book, and will gently introduce you to many other pages from the hubs above. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;e-book versions&lt;/a&gt; are also available.</source>
      <translation>FreeCAD マニュアルはこのウィキの情報をもっと直線的に見るもう1つの方法です。本のように読めるよう作られていて、上記のハブのたくさんのページを少しずつ読んでいくことができるでしょう。&lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;電子書籍バージョン&lt;/a&gt;も利用可能です。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="59"/>
      <source>Workbenches documentation</source>
      <translation>ワークベンチのドキュメント</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="60"/>
      <source>These are the help pages of all the workbenches currently installed on this computer.</source>
      <translation>このコンピューターに現在インストールされている全てのワークベンチのヘルプページがあります。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="61"/>
      <source>Getting help from the community</source>
      <translation>コミュニティから助けを得る</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="62"/>
      <source>The &lt;a href="http://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt; is a great place to get help from other FreeCAD users and developers. The forum has many sections for different types of issues and discussion subjects. If in doubt, post in the more general &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; section.</source>
      <translation>&lt;a href="http://forum.freecadweb.org"&gt;FreeCAD フォーラム&lt;/a&gt; は他の FreeCAD ユーザーや開発者から手助けを得られるすばらしい場所です。フォーラムはさまざまな種類の問題や議題を扱うたくさんのセクションがあります。もしどこに投稿すればいいかわからなければ一般的な話題を扱う &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;FreeCAD 使用時のヘルプ&lt;/a&gt; に投稿してください。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="63"/>
      <source>If it is the first time you are posting on the forum, be sure to &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;read the guidelines&lt;/a&gt; first!</source>
      <translation>初めてフォーラムに投稿する場合は最初に&lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;ガイドラインを読んで&lt;/a&gt;確認してください。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="64"/>
      <source>FreeCAD also maintains a public &lt;a href="https://www.freecadweb.org/tracker"&gt;bug tracker&lt;/a&gt; where anybody can submit bugs and propose new features. To avoid causing extra work and give the best chances to see your bug solved, make sure you read the &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;bug submission guide&lt;/a&gt; before posting.</source>
      <translation>FreeCAD には公開&lt;a href="https://www.freecadweb.org/tracker"&gt;バグトラッカー&lt;/a&gt;も用意されていて、誰でもバグや新しい機能の提案を投稿することができます。余分な作業を発生させず、見つけたバグを解決できる可能性を上げるために、投稿する前には必ず&lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;バグ報告ガイドライン&lt;/a&gt;を読んでください。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="65"/>
      <source>Available addons</source>
      <translation>利用可能なアドオン</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="66"/>
      <source>Below is a list of available extra workbenches that can be added to your FreeCAD installation. Browse and install them from menu Tools -&gt; Addons manager. You can learn more about any of them by clicking the links below.</source>
      <translation>以下はインストールしたFreeCADに追加して利用できる追加ワークベンチのリストです。メニューの [ツール] - [Addon manager] で表示とインストールを行なってください。以下のリンクをクリックするとそれぞれのワークベンチについてさらに詳しく知ることができます。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="67"/>
      <source>If not bundled with your FreeCAD version, install the FreeCAD documentation package to get documentation hubs, workbench help and individual command documentation without an internet connection.</source>
      <translation>もしドキュメントのバンドルされていないFreeCADバージョンであるならば、FreeCADドキュメントパッケージをドキュメンテーション・ハブよりインストールすることで、ワークベンチのヘルプや各コマンドのドキュメントをインターネット接続なしでも利用できます。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="68"/>
      <source>Cannot fetch information from GitHub. &lt;a href="EnableDownload.py"&gt;Authorize FreeCAD to access the internet&lt;/a&gt; and reload the Start page.</source>
      <translation>GitHubから情報をフェッチできませんでした。 &lt;a href="EnableDownload.py"&gt;FreeCADに、インターネットへアクセスできる権限を与える&lt;/a&gt; そして開始ページを再読み込みをして下さい。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="69"/>
      <source>Recent commits</source>
      <translation>最近のコミット</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
      <source>Below are the latest changes added to the &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCAD source code&lt;/a&gt;. These changes might not reflect yet in the FreeCAD version that you are currently running. Check the &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;available options&lt;/a&gt; if you wish to obtain a development version.</source>
      <translation>以下のは、最新の改良が加えられた&lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCADのソースコード&lt;/a&gt;です。これらの改良は、あなたが現在実行しているFreeCADのバージョンにはまだ反映されていない場合があります。 開発版の入手をご希望の場合は &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;利用可能なオプション&lt;/a&gt;より確認して下さい。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>See all commits on github</source>
      <translation>GitHubのコメントを全て参照</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
      <translation>メニュー「編集-&gt; プレファレンス -&gt; 開始-&gt; 追加フォルダの表示」にて、表示するカスタムフォルダを構成できます。</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
      <source>version</source>
      <translation>バージョン</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="74"/>
      <source>build</source>
      <translation>ビルド</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="75"/>
      <source>Create new...</source>
      <translation>新規作成...</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="76"/>
      <source>Unknown</source>
      <translation>不明</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="77"/>
      <source>Forum</source>
      <translation>フォーラム</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="78"/>
      <source>The latest posts on the &lt;a href="https://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt;:</source>
      <translation>&lt;a href="https://forum.freecadweb.org"&gt;FreeCAD フォーラム&lt;/a&gt;の最新の投稿:</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="79"/>
      <source>To open any of the links above in your desktop browser, Right-click -&gt; Open in external browser</source>
      <translation>上記のリンクをデスクトップのブラウザーで開きたい場合は、「右クリック-&gt;外部ブラウザーで開く」の手順で開けます</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="80"/>
      <source>Creation date</source>
      <translation>作成日時</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="81"/>
      <source>Last modification</source>
      <translation>最終変更</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Notes</source>
      <translation>ノート</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Open start page preferences</source>
      <translation type="unfinished">Open start page preferences</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <location filename="../../Workbench.cpp" line="65"/>
      <source>Start page</source>
      <translation>スタートページ</translation>
    </message>
  </context>
  <context>
    <name>CmdStartPage</name>
    <message>
      <location filename="../../Command.cpp" line="44"/>
      <source>Start</source>
      <translation>開始</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="45"/>
      <source>Start Page</source>
      <translation>スタートページ</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Displays the start page in a browser view</source>
      <translation>ブラウザービューでスタートページを表示</translation>
    </message>
  </context>
  <context>
    <name>DlgStartPreferences</name>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="14"/>
      <source>Start page options</source>
      <translation>スタートページのオプション</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="20"/>
      <source>Start page template</source>
      <translation>スタートページのテンプレート</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="26"/>
      <source>An optional HTML template that will be used instead of the default start page.</source>
      <translation>オプションのHTMLテンプレートを、既定の開始ページの代替えとして用います。</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="42"/>
      <source>Contents</source>
      <translation>コンテンツ</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="48"/>
      <source>Show forum</source>
      <translation>フォーラムを表示</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="55"/>
      <source>Show examples folder contents</source>
      <translation>サンプルフォルダの内容を表示</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="62"/>
      <source>Show additional folder</source>
      <translation>追加フォルダを表示</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="69"/>
      <source>If you want the examples to show on the first page</source>
      <translation>最初のページにて、作例を表示させたい</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="91"/>
      <source>If this is checked, the latest posts from the FreeCAD forum will be displayed on the Activity tab</source>
      <translation>ここにチェックを入れると、FreeCADフォーラムからの最新の投稿が現在のタブに表示されます</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="110"/>
      <source>An optional custom folder to be displayed at the bottom of the first page</source>
      <translation>オプションのカスタムフォルダを最初のページで表示させます</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="126"/>
      <source>Show notepad</source>
      <translation>メモ帳を表示</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="133"/>
      <source>Shows a notepad next to the file thumbnails, where you can keep notes across FreeCAD sessions</source>
      <translation>ファイルのサムネイルの隣にメモ帳を表示させて、FreeCAD セッションの全般においてメモを保存できます。</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="155"/>
      <source>Fonts and colors</source>
      <translation>フォント及び色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="167"/>
      <source>The background of the main start page area</source>
      <translation>メインスタートページ領域の背景</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="187"/>
      <source>Background color</source>
      <translation>背景色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="199"/>
      <source>in FreeCAD</source>
      <translation>FreeCAD</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="218"/>
      <source>In external browser</source>
      <translation>外部ブラウザー</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="236"/>
      <source>Background color gradient down</source>
      <translation>下向きグラデーション背景色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="249"/>
      <source>The color of the version text</source>
      <translation>バージョンの文字色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="269"/>
      <source>Link color</source>
      <translation>リンクの色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="276"/>
      <source>An optional image to display as background</source>
      <translation>背景として表示するオプション画像</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="289"/>
      <source>If this is checked, if a style sheet is specified in General preferences, it will be used and override the colors below</source>
      <translation>ここをチェックすると、一般プレファレンスで指定されているスタイルシートが使用されて、以後から上書きされます。</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="308"/>
      <source>Page background color</source>
      <translation>ページ背景色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="321"/>
      <source>The color of the text on the main pages</source>
      <translation>メインページの文字色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="341"/>
      <source>Background image</source>
      <translation>背景画像</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="348"/>
      <source>Page text color</source>
      <translation>ページ文字色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="361"/>
      <source>The color of the links</source>
      <translation>リンクの色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="387"/>
      <source>The background color of the boxes inside the pages</source>
      <translation>ページ内におけるボックスの背景色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="407"/>
      <source>Box background color</source>
      <translation>ボックスの背景色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="420"/>
      <source>The background color behind the panels</source>
      <translation>パネルの背景色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="449"/>
      <source>The down gradient for the background color (currently unsupported)</source>
      <translation>背景色用の下向きグラデーション (現在はサポートされていません)</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="472"/>
      <source>Open links</source>
      <translation>リンクを開く</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="479"/>
      <source>Background text color</source>
      <translation>テキスト背景色</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="486"/>
      <source>Use FreeCAD style sheet</source>
      <translation>FreeCAD スタイルシートを使用</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="493"/>
      <source>Font family</source>
      <translation>フォントの種類</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="502"/>
      <source>The font family to use on the start page. Can be a font name or a comma-separated series of fallback fonts</source>
      <translation>スタートページに用いるフォントファミリー。フォント名またはコンマで区切られた一連の代替えフォントにします</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="508"/>
      <source>Arial,Helvetica,sans</source>
      <translation>Arial,Helvetica,sans</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="521"/>
      <source>The base font size to use for all texts of the Start page</source>
      <translation>開始ページのテキスト全てに使用する基本フォントサイズ</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="524"/>
      <source>px</source>
      <translation>px</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="542"/>
      <source>Use gradient for New File icon</source>
      <translation>新規フォイルのアイコンにグラデーションを用いる</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="568"/>
      <source>Options</source>
      <translation>オプション</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="577"/>
      <source>Should the start page be closed after loading?</source>
      <translation>読み込み後に、スタートページを閉じたいですか？</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="596"/>
      <source>Switch workbench after loading</source>
      <translation>読み込みの後でワークベンチを切り替え</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="603"/>
      <source>Close start page after loading</source>
      <translation>読み込みの後でスタートページを閉じる</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="610"/>
      <source>Close &amp; switch on file open</source>
      <translation>閉じて、ファイルを開く</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="617"/>
      <source>If FreeCAD is started by opening a file, apply the two settings above</source>
      <translation>ファイルオープンで FreeCAD を開始する場合、上の2つの設定を適用</translation>
    </message>
  </context>
</TS>
